#!/bin/bash
#
# Generic cron script to maintain a given udptap set up
#
# The configuration defines:
# TAP = the tap device to use
# BR = bridge to add the tap to
# IP = the local IP for the tap
# IPV4 = flag for "pure" ipv4
# PORT = the local UDP port to service
# VPN = the udptap remotes list
# VERBOSE= empty, -v, -vv, or -vvv (optional; empty for non-verbose)
# 
TAPUSER=root
UDPTAP=/usr/local/sbin/udptap
FLOCK=/usr/bin/flock
LOCK="/var/lock/udptap-$1.log"

die() { echo "$*" >&2 ; exit 1 ; }

. /etc/udptap/conf.d/$1.conf || die Missing configuration for $1

[ -z "$PORT" ] && die unknown PORT for $1
[ -z "$VPN" ] && die unknown VPN for $1

V="${VERBOSE#-v}"
[ -z "${V#v}" ] || [ -z "${V#vv}" ] || \
    die VERBOSE must be empty, -v, -vv, or -vvv

# Spawn the updtap server, with flock on $LOCK
{
    $FLOCK -n 9 || exit 0
    ARGS=( $VERBOSE )
    [ -z "$IPV4" ] || ARGS+=( -4 )
    if [ -n "$TAP" ] ; then
	/sbin/ip tuntap add "$TAP" mode tap user $TAPUSER >&2
	/sbin/ifconfig "$TAP" $IP up >&2
	[ -z "$BR" ] || /sbin/brctl addif "$BR" "$TAP" || die invalid BR for $1
	ARGS+=( -t $TAP )
    fi
    ARGS+=( $PORT )
    ARGS+=( "${VPN[@]}" )
    echo $UDPTAP "${ARGS[@]}" >&2
    exec $UDPTAP "${ARGS[@]}"
} 9> "$LOCK" &
